熔炉 (豆瓣)
Description: 熔炉电影简介和剧情介绍,熔炉影评、图片、预告片、影讯、论坛、在线购票
Keywords: 熔炉,도가니,熔炉影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.21豆瓣电影Top250

# 熔炉 도가니 (2011)

更新描述或海报

导演: 黄东赫
编剧: 黄东赫 / 孔枝泳
主演: 孔刘 / 郑有美 / 金贤秀 / 郑仁絮 / 白承焕 / 张光 / 金民尚 / 林贤成 / 金周灵 / 严孝燮 / 全国焕 / 崔镇浩 / 金志映 / 严智星 / 许在浩 / 张素妍
类型: 剧情
制片国家/地区: 韩国
语言: 韩语
上映日期: 2011-09-22(韩国)
片长: 125分钟
又名: 无声呐喊(港) / 漩涡 / Silenced / The Crucible
IMDb: tt2070649
豆瓣评分
引用
9.4
890161人评价
5星
71.5%
4星
25.0%
3星
3.3%
2星
0.2%
1星
0.1%
好友评分
你关注的人看过这部作品的平均分
9.0
2人评价
好于 99% 剧情片
想看 看过
评价:
推荐

## 熔炉的剧情简介 · · · · · ·

来自首尔的哑语美术老师仁浩（孔宥 饰）来到雾津，应聘慈爱聋哑人学校。天降大雾，他意外撞车，维修时邂逅了人权组织成员柔珍（郑有美 饰）。仁浩妻子早亡，8岁女儿天生哮喘由祖母照看，所以他不辞辛苦谋职养家。然而，双胞胎的校长与教导主任竟逼仁浩索贿5千万韩元。同时，仁浩逐渐发现学校笼罩着一种紧张压抑的气氛，令人窒息。有三个孩子引人关注：聪颖的金妍斗（金贤秀 饰）、贪吃的陈宥利（郑仁絮 饰）和弟弟自杀身亡的全民秀（白承焕 饰），民秀总是满脸淤青。下课后，仁浩还听到女厕所中有呼喊与哭泣，在门卫的阻拦下他未深究。之后。他意外目睹了校长行贿警察，教导员毒打民秀，宿导溺罚妍斗的行径。一个惊天的隐秘被慢慢揭开，真相令韩国震惊……
本片取材于2005年光州一所聋哑障碍人学校的真实事件，改编自韩国作家孔枝泳的同名小说。 ©豆瓣

## 熔炉的演职员 · · · · · · ( 全部 29 )

- 黄东赫 导演
- 孔刘 饰 姜仁浩
- 郑有美 饰 徐幼真
- 金贤秀 饰 金妍豆
- 郑仁絮 饰 陈琉璃
- 白承焕 饰 全民秀

## 熔炉的视频和图片 · · · · · · ( 预告片4 | 添加视频评论 | 图片1010 · 添加 )

## 熔炉的获奖情况 · · · · · · ( 全部 )

- 第49届韩国电影大钟奖
- 最佳影片(提名)

- 第49届韩国电影大钟奖
- 最佳女配角(提名)
- 金贤秀

## 喜欢这部电影的人也喜欢 · · · · · ·

  猫鼠游戏

  杀人回忆

  素媛

  恐怖直播

  七宗罪

  小丑

  沉默的羔羊

  三块广告牌

  烈日灼心

  看不见的客人

我要写短评

## 熔炉的短评 · · · · · · ( 全部 209107 条 )

热门 / 最新 / 好友

### 12773 有用 C° 看过 2012-01-03 07:16:41

他们至少有电影的力量在支撑着弱势群体，而我们呢？因为【熔炉】的上映，一部关于【性暴力犯罪处罚特别法部分修订法律案】目前已通过韩国国会正式颁布，当时的嫌疑人也已被警方逮捕，【熔炉】让我们看到一部现实题材影片所蕴含的巨大能量。有时候一部电影真的可以改变一个世界！

### 11395 有用 茱湮河 看过 2011-12-28 03:27:03

想起一级恐惧的片头台词来：想找公平就到妓院，想被人干才到法庭。深雾中到处是颤栗的呻吟。

### 6906 有用 又又 看过 2011-12-30 13:13:27

這個世界的絕望在於，眼睜睜地看著那麼多的不公不平每天都在身邊發生，自己再怎麼努力卻依舊無可奈何；而這個世界的希望也在於，明知是蚍蜉撼大樹，卻還是有那麼一群人執著地選擇了這一條艱難而幾近不可能的路。

### 4431 有用 qw-p 看过 2011-12-30 20:48:57

我们无法改变世界，但我们可以选择不被世界改变...

### 3889 有用 Doublebitch 看过 2012-01-03 12:43:01

当邪恶的力量已经渗透至社会的每个角落尤其是当权者手中，我们还他妈向谁去央求公平和自由

> 更多短评 209107条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 熔炉的影评 · · · · · · ( 全部 4081 条 )

热门 / 最新 / 好友
巴斯特德 2011-12-30 23:21:51

## 孩子们，世界很好，你们还好吗？

影片改编自真实事件。 穿过幽暗狭长的隧道，便是雾津。漫天浓郁的雾气，两条刚刚失去，尸体还温热的生命，还有那块绿色的交通指示牌，无声地告诉姜仁浩：雾津欢迎你。 也许每个生命来到这个世界上本来应该是平等的。如今似乎人们已经达成了某种共识，那就是那句仿佛是刻在亘古... (展开)
11681 329 779回应 收起
密斯酱 2012-07-10 01:19:25

## 《熔炉》始末

年初看完《熔炉》之后，我的心情和大家一样，似有千言万语无限愤怒，却又不知如何说出，只能化成无聊的的九个字“没看着急，看了郁闷，唉。。。” 今天无意间看到了世界末日辣椒酱贴出的一个视频，在这里要感谢她！ 心脏再度被重重一击，但这次不仅仅是因为电影，而是《熔炉》... (展开)
7642 202 546回应 收起
huanyouyo 2011-10-24 18:13:14

## 2011年，一个让整个韩国战栗的真相被揭露！【整理】

听起来有些不可置信， 但却是在一所聋哑儿童学校中发生的真实事件。 从2000年起，校长串通手下的老师们利用卑鄙下流的手段，对就读校内的聋哑孩子们施行了长达５年之久的虐待和性暴力行为。这件丑陋得让人不想提及的事件，却可惜是真真切切的事实。 现在，到了讲述这件骇人听闻... (展开)
2667 316 190回应 收起
德小科 2013-02-01 22:41:03

## 我今晚为什么选择了[熔炉]

今晚在学校里放了这部电影，结果从头到尾大家表现冷淡，不断有人离场，说说笑笑，甚至各种不满。到最后，有一位女生站起来斥责我：能不能换一个电影？你让大家安静地看，可你有没有考虑过我们也有选择的权利…… 百思不得其解的夜晚，我在微博上发表了这篇长回复。 ※我今晚... (展开)
2767 108 620回应 收起
小小农 2012-01-02 20:23:34

## 《熔炉》烘烤集体的良知

看韩国影片《熔炉》时，我脑中闪现过另一个真实的影子，忘记这则新闻报道于哪年哪月了，报道的题目便是《少女在敬老院遭多人强奸怀孕》，事件是失去双亲的一对姐弟，被送到养老院，12岁的姐姐三年里遭到数人强奸，直到怀孕才被亲戚发现。结果是少女的亲人找养老院领导，找当地... (展开)
1438 30 126回应 收起
Shiva 2011-12-31 22:14:54

## 会车时请关掉远光灯

这篇影评可能有剧透

在开篇的天气预报里，雾津，这个虚构的名字就这样大摇大摆地跟在首尔、大田和光州的后面，进入人们的视野，仿佛在强调着这个白色浓雾之都或真或假的存在。然而，被浓雾笼罩着的不仅仅是这个城市而已。 一场因远光灯引起的车祸，让我不禁联想到韩寒的年末三响炮。这几篇最近被... (展开)
1064 120 173回应 收起
夏空 2012-10-02 19:49:10

## 韩国真实电影《熔炉》致性侵残障儿童案再调查

2012年01月16日 《方圆》杂志 作者 杜向前 《熔炉》的“熔炉效应” 　　“他无法听到，也无法说话。”这是2011年韩国一部名为《熔炉》的电影中的一句台词。 　　在影片的最后，美术老师姜仁浩抱着民秀这位用生命来争取和捍卫承诺、尊严、正义的聋哑孩子的遗像，在警察驱... (展开)
669 27 28回应 收起
周 2012-01-11 22:34:34

## 这个世界 比你想象的还要，不堪

电影改编自真实的故事。 在我看到电影的消息刚出来时 我是不打算看的。我很喜欢孔侑，可是我讨厌真实，讨厌不堪甚至愤恨。 因为我的情绪会比通常人更加细微，所以我会避免让自己看一些对这个世界不好的事情。我希望，在我眼中这个世界是美好的。 记得看无头骑士异闻录时，并... (展开)
397 16 50回应 收起
万一 2012-01-02 23:46:20

## 伟大的反抗者、小说作者、导演与演员

真实的事件。直到电影上映之后，影片中的相关11名犯罪人才在同年12月29日被重新抓捕。没有反抗者、小说家导演和演员的坚持，就不会有迟来的正义。 正义终究是正义，虽然有虚伪、强大的韩国基督教会组织庇护，罪恶到底得到惩罚。 不能不让人感慨，韩国的民主制... (展开)
222 19 21回应 收起

> 更多影评 4081篇

添加新讨论

## 讨论区 · · · · · ·

熔炉的结尾是教父的开始 | 来自佩恩轮回 |  | 2022-11-21 00:50:32
在哪里可以看到这个电影？ | 来自小橙子 | 1 回应 | 2022-11-18 20:52:52
某人也就看过超人绿巨人了 | 来自碎梦 | 2 回应 | 2022-11-14 01:42:55
韩国电影，真实事件改编界的天花板 | 来自一米阳光 | 2 回应 | 2022-11-14 01:27:10
《熔炉》观后感 | 来自戏中人 |  | 2022-11-13 13:47:19

> 去这部影片的讨论区（全部661条）

## 关于《熔炉》的问题 · · · · · · ( 全部73个 )

- 为什么叫熔炉，有什么含义吗？ 22人回答
- 看到百度上面写上映时间是2011年，又说事情是2005年发生的，那是来自2011年哪个真实事件？ 16人回答

> 全部73个问题

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 2011 豆瓣电影【口碑榜】 (影志)
- 木卫清单｜你不应该错过的100部韩国电影 (木卫二)
- 2011新电影（这些，可以期待） (桃桃林林)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)

## 谁在看这部电影 · · · · · ·

- Vcr
  1分钟前 看过
- 以绝望挥剑
  1分钟前 看过
- 豆友44kpRS0XsA
  2分钟前 想看

1473441人看过 / 447666人想看

订阅熔炉的评论:
feed: rss 2.0